
body {
	font-family: "Avenir Next", Helvetica, Arial, sans-serif;
	padding:1em;
	margin:auto;
	max-width:42em;
	background:#fefefe;
}

h1, h2, h3, h4, h5, h6 {
	font-weight: bold;
}

h1 {
	color: #000000;
	font-size: 28pt;
}

h2 {
	border-bottom: 1px solid #CCCCCC;
	color: #000000;
	font-size: 24px;
}

h3 {
	font-size: 18px;
}

h4 {
	font-size: 16px;
}

h5 {
	font-size: 14px;
}

h6 {
	color: #777777;
	background-color: inherit;
	font-size: 14px;
}

hr {
	height: 0.2em;
	border: 0;
	color: #CCCCCC;
	background-color: #CCCCCC;
}

p, blockquote, ul, ol, dl, li, table, pre {
	margin: 15px 0;
}

img {
	max-width: 100%;
}

table {
	border-collapse: collapse;
	width: 100%;
}

table, th, td {
	border: 1px solid #EAEAEA;

	border-radius: 3px;
	padding: 5px;
}

tr:nth-child(even) {
  background-color: #F8F8F8;
}

a, a:visited {
	color: #4183C4;
	background-color: inherit;
	text-decoration: none;
}

#message {
	border-radius: 6px;
	border: 1px solid #ccc;
	display:block;
	width:100%;
	height:60px;
	margin:6px 0px;
}

button, #ws {
	font-size: 10pt;
	padding: 4px 6px;
	border-radius: 5px;
	border: 1px solid #bbb;
	background-color: #eee;
}

code, pre, #ws, #message {
	font-family: Monaco, monospace;
	font-size: 10pt;
	border-radius: 3px;
	background-color: #F8F8F8;
	color: inherit;
}

code {
	border: 1px solid #EAEAEA;
	margin: 0 2px;
	padding: 0 5px;
}

pre {
	border: 1px solid #CCCCCC;
	background-color: rgb(43, 43, 43);
	color: rgb(248, 248, 242);
	overflow: auto;
	padding: 4px 8px;
}

pre span.ch, pre span.c1 {
    color: grey;
}
pre span.kn, pre span.k, pre span.ow, pre span.p {
    color: orange
}
pre span.nd {
    color: gold
}
pre span.nf {
    color: yellow
}
pre span.s2, pre span.s1, pre span.si {
    color: green
}
pre span.nb, pre span.mi {
    color: violet
}
pre > code {
	border: 0;
	margin: 0;
	padding: 0;
}

#ws { background-color: #f8f8f8; }

.send { color:#77bb77; }
.server { color:#7799bb; }
.error { color:#AA0000; }

